@@ -72,13 +72,14 @@ GMenuModel* Menu::menu_model()
 std::vector<Appointment>
 Menu::get_display_appointments(const std::vector<Appointment>& appointments_in,
                                const DateTime& now,
-                               unsigned int max_items)
+                               unsigned int max_items,
+                               const bool include_alarms)
 {
     std::vector<Appointment> appointments;
     std::copy_if(appointments_in.begin(),
                  appointments_in.end(),
                  std::back_inserter(appointments),
-                 [now](const Appointment& a){return a.end >= now;});
+                 [now, include_alarms](const Appointment& a){return a.end >= now && (!a.is_alarm() || include_alarms);});
 
     if (appointments.size() > max_items)
     {
@@ -186,6 +187,9 @@ protected:
         m_state->settings->show_events.changed().connect([this](bool){
             update_section(Appointments); // showing events got toggled
         });
+        m_state->settings->show_alarms.changed().connect([this](bool){
+            update_section(Appointments); // showing alarms got toggled
+        });
         m_state->calendar_upcoming->date().changed().connect([this](const DateTime&){
             update_upcoming(); // our m_upcoming is planner->upcoming() filtered by time
         });
@@ -240,7 +244,9 @@ protected:
 
         auto upcoming = get_display_appointments(
             m_state->calendar_upcoming->appointments().get(),
-            begin
+            begin,
+            5,
+            m_state->settings->show_alarms.get()
         );
 
         if (m_upcoming != upcoming)
@@ -268,10 +274,6 @@ protected:
         return m_serialized_alarm_icon;
     }
 
-    std::vector<Appointment> m_upcoming;
-
-private:
-
     GVariant* get_serialized_calendar_icon()
     {
         if (G_UNLIKELY(m_serialized_calendar_icon == nullptr))
@@ -284,6 +286,10 @@ private:
         return m_serialized_calendar_icon;
     }
 
+    std::vector<Appointment> m_upcoming;
+
+private:
+
     void create_gmenu()
     {
         g_assert(m_submenu == nullptr);
@@ -428,29 +434,32 @@ private:
     {
         auto menu = g_menu_new();
 
-        if ((profile==Desktop) && m_state->settings->show_events.get())
+        if (m_state->settings->show_events.get())
         {
-            add_appointments (menu, profile);
-
-            if (m_actions->desktop_has_calendar_app())
+            if (profile==Desktop)
             {
-                // add the 'Add Event…' menuitem
-                auto menu_item = g_menu_item_new(_("Add Event…"), nullptr);
-                const gchar* action_name = "indicator.desktop.open-calendar-app";
-                auto v = g_variant_new_int64(0);
-                g_menu_item_set_action_and_target_value(menu_item, action_name, v);
-                g_menu_append_item(menu, menu_item);
-                g_object_unref(menu_item);
-            }
-        }
-        else if (profile==Phone)
-        {
-            auto menu_item = g_menu_item_new (_("Clock"), "indicator.phone.open-alarm-app");
-            g_menu_item_set_attribute_value (menu_item, G_MENU_ATTRIBUTE_ICON, get_serialized_alarm_icon());
-            g_menu_append_item (menu, menu_item);
-            g_object_unref (menu_item);
+                add_appointments (menu, profile);
 
-            add_appointments (menu, profile);
+                if (m_actions->desktop_has_calendar_app())
+                {
+                    // add the 'Add Event…' menuitem
+                    auto menu_item = g_menu_item_new(_("Add Event…"), nullptr);
+                    const gchar* action_name = "indicator.desktop.open-calendar-app";
+                    auto v = g_variant_new_int64(0);
+                    g_menu_item_set_action_and_target_value(menu_item, action_name, v);
+                    g_menu_append_item(menu, menu_item);
+                    g_object_unref(menu_item);
+                }
+            }
+            else if (profile==Phone)
+            {
+                auto menu_item = g_menu_item_new (_("Clock"), "indicator.phone.open-alarm-app");
+                g_menu_item_set_attribute_value (menu_item, G_MENU_ATTRIBUTE_ICON, get_serialized_alarm_icon());
+                g_menu_append_item (menu, menu_item);
+                g_object_unref (menu_item);
+
+                add_appointments (menu, profile);
+            }
         }
 
         return G_MENU_MODEL(menu);
@@ -598,6 +607,7 @@ protected:
     {
         // are there alarms?
         bool has_alarms = false;
+        bool has_non_alarm_events = false;
         for(const auto& appointment : m_upcoming)
         {
             has_alarms = appointment.is_alarm();
@@ -606,19 +616,33 @@ protected:
             {
                 break;
             }
+            else
+            {
+                has_non_alarm_events = true;
+            }
         }
 
+
         GVariantBuilder b;
         g_variant_builder_init(&b, G_VARIANT_TYPE_VARDICT);
         g_variant_builder_add(&b, "{sv}", "title", g_variant_new_string (_("Time and Date")));
         g_variant_builder_add(&b, "{sv}", "visible", g_variant_new_boolean (TRUE));
-        if (has_alarms)
+        if (has_alarms || has_non_alarm_events)
+
         {
             auto label = m_formatter->header.get();
-            auto a11y = g_strdup_printf(_("%s (has alarms)"), label.c_str());
+            auto a11y = g_strdup_printf(_("%s (has events)"), label.c_str());
             g_variant_builder_add(&b, "{sv}", "label", g_variant_new_string(label.c_str()));
             g_variant_builder_add(&b, "{sv}", "accessible-desc", g_variant_new_take_string(a11y));
-            g_variant_builder_add(&b, "{sv}", "icon", get_serialized_alarm_icon());
+
+            if (has_alarms && m_state->settings->show_alarms.get())
+            {
+                g_variant_builder_add(&b, "{sv}", "icon", get_serialized_alarm_icon());
+            }
+            else
+            {
+                g_variant_builder_add(&b, "{sv}", "icon", get_serialized_calendar_icon());
+            }
         }
         else
         {
